/*
 * TASK:       impulse (Author's solution)
 * AUTHOR:     Veselin Georgiev
 * SOLUTION:   DP on current sample position and width
 * COMPLEXITY: O(N*W) time, O(W) memory, where N is num samples, W is the max number of bits (17).
 */
#include <stdio.h>
#include <assert.h>

const int INF = 999666111;
int n;
int answer;
int write_stats;

void read_input(void)
{
	scanf("%d", &n);
}

void write_output(void)
{
	printf("%d\n", answer);
	if (write_stats) {
		fprintf(stderr, "Input bits: %d\nOutput bits: %d\nCompression: %.2lf%%\n", n * 16, answer, ((n * 16 - answer) * 100.0 / (n * 16)));
	}
}

static inline int bits_required(int x)
{
	if (x < 0) x = -x;
	assert(x <= 65535);
	for (int bits = 1; bits <= 17; bits++)
		if ((1 << (bits - 1)) - 1 >= x)
			return bits;
	return 17;
}

static inline int change_cost(int from_bits)
{
	return from_bits + 4;
}

static inline int min(int a, int b)
{
	return (a < b) ? a : b;
}

void solve(void)
{
	int dp[2][20]; // index % 2, num bits
	//
	int prev_sample = 0;
	for (int j = 1; j < 17; j++) dp[1][j] = INF;
	dp[1][17] = 0; // initial state: length = 0, W = 17, prev_sample = 0
	//
	for (int i = 0; i < n; i++) {
		int sample;
		// read sample:
		scanf("%d", &sample);
		int delta = sample - prev_sample;
		prev_sample = sample;

		// compute bits required and only consider streams at least this wide:
		int min_bits = bits_required(delta);
		int cur = i % 2, prev = (i + 1) % 2;
		for (int j = 1; j <= 17; j++)
			dp[cur][j] = j < min_bits ? INF : dp[prev][j];

		// see what is the best current width we might change from:
		int min_length = INF;
		for (int j = 1; j <= 17; j++)
			min_length = min(min_length, dp[prev][j] + change_cost(j));

		// try to update any hopelessly large streams:
		for (int j = min_bits; j <= 17; j++)
			dp[cur][j] = min(dp[cur][j], min_length);

		// add the current delta to all active streams:
		for (int j = min_bits; j <= 17; j++)
			dp[cur][j] += j;
	}

	// compute answer:
	answer = INF;
	int cur = (n - 1) % 2;
	for (int j = 1; j <= 17; j++) answer = min(answer, dp[cur][j]);
}

int main(int argc, char** argv)
{
	if (argc == 2) write_stats = 1;
	read_input();
	solve();
	write_output();
	return 0;
}
