#!/usr/bin/python
import random, math, wave, sys, pdb

def write_test(no, data):
	print "Writing test #%02d (%d samples)" % (no, len(data))
	sys.stdout.flush()
	f = open("../tests/impulse.%02d.in" % no, "w")
	f.write("%d\n" % len(data))
	assert len(data) <= 10**6
	for sample in data:
		assert -32768 <= sample <= 32767
		f.write("%d\n" % sample)
	f.close()

def test_all_bits(n):
	"""random, all sizes from 1 to 16 bits:"""
	data = []
	for bits in xrange(1, 17):
		maxSample = 2**(bits - 1) - 1
		for i in xrange(n/16):
			data.append(random.randint(-maxSample, +maxSample))
	return data

def test_loud_and_quiet():
	"""big maximum deltas, interspersed with short bursts of nearly constant values"""
	data = [-32768, 32767] * 500
	for i in xrange(10):
		length = random.randint(1, 15)
		median = random.randint(-10000, 10000)
		position = random.randint(0, len(data) - 1 - length)
		for j in xrange(length):
			data[position + j] = random.randint(median - 5, median + 5)
	return data

def test_ever_increasing_delta(n, multiplier=1):
	"""Test with delta that increases all the time"""
	delta = 1
	sample = 0
	sign = +1
	data = []
	for i in xrange(n):
		sample += delta * sign
		sign = -sign
		delta += multiplier
		data.append(sample)
	return data

def test_sinusoid(n):
	"""Sinusoidal sweep from 100 Hz to 15 kHz and back."""
	t = 0.0
	data = []
	for i in xrange(n):
		freq_interpolate = 0.0
		if i < n/2:
			freq_interpolate = i / float(n/2)
		else:
			freq = 2 - i / float(n/2)
		freq = 100 + (15000 - 100) * freq_interpolate
		kHz = 44100
		# if freq was 1 Hz, then t should be advanced with 2 * pi / 44100; one revolution per second:
		t += 2 * math.pi * freq / kHz
		data.append(int(math.sin(t) * 20000))
	return data

def test_from_wav_file(filename, divide_by=1, extend=False):
	data = []
	source = wave.open("wavs/" + filename, "r")
	n = source.getnframes()
	wav = source.readframes(n)
	source.close()
	#
	# convert:
	for i in xrange(n):
		lowbyte = ord(wav[i * 2])
		hibyte  = ord(wav[i * 2 + 1])
		x = lowbyte + hibyte * 256
		if x > 32767:
			x -= 65536
		data.append(x / divide_by)
	if extend:
		data += [0] * (10**6-len(data))
	return data
	
def main(args):

	random.seed(42)

	write_test( 1, [0] * 100) # 100 zeros; answer = 21 + 100
	write_test( 2, test_all_bits(320))
	write_test( 3, test_loud_and_quiet())
	write_test( 4, test_ever_increasing_delta(1000, 20))
	write_test( 5, [random.randint(-32768, 32767) for _ in xrange(500)])
	write_test( 6, test_sinusoid(150000))
	write_test( 7, test_from_wav_file("sam.wav", divide_by=64))    # the whole file should fit in 10 bits encoding
	write_test( 8, test_from_wav_file("kurtis.wav", extend=True))  # the source is slightly less, make it exactly 1000000 samples
	write_test( 9, test_from_wav_file("cool.wav"))                 # the source is kinda quiet and doesn't have lots of high frequency; should compress well
	write_test(10, test_from_wav_file("sam.wav", extend=True))     # the source is slightly less, make it exactly 1000000 samples

if __name__ == "__main__":
	main(sys.argv)
